==> openshift-model-operatorhub-4.13.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/RequirementStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RequirementStatusFluent<A extends RequirementStatusFluent<A>> extends Fluent<A> {


    public A addToDependents(int index,DependentStatus item);
    public A setToDependents(int index,DependentStatus item);
    public A addToDependents(DependentStatus... items);
    public A addAllToDependents(Collection<DependentStatus> items);
    public A removeFromDependents(DependentStatus... items);
    public A removeAllFromDependents(Collection<DependentStatus> items);
    public A removeMatchingFromDependents(io.fabric8.kubernetes.api.builder.Predicate<DependentStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDependents instead.
 * @return The buildable object.
 */
@Deprecated public List<DependentStatus> getDependents();
    public List<DependentStatus> buildDependents();
    public DependentStatus buildDependent(int index);
    public DependentStatus buildFirstDependent();
    public DependentStatus buildLastDependent();
    public DependentStatus buildMatchingDependent(io.fabric8.kubernetes.api.builder.Predicate<DependentStatusBuilder> predicate);
    public Boolean hasMatchingDependent(io.fabric8.kubernetes.api.builder.Predicate<DependentStatusBuilder> predicate);
    public A withDependents(List<DependentStatus> dependents);
    public A withDependents(DependentStatus... dependents);
    public Boolean hasDependents();
    public RequirementStatusFluent.DependentsNested<A> addNewDependent();
    public RequirementStatusFluent.DependentsNested<A> addNewDependentLike(DependentStatus item);
    public RequirementStatusFluent.DependentsNested<A> setNewDependentLike(int index,DependentStatus item);
    public RequirementStatusFluent.DependentsNested<A> editDependent(int index);
    public RequirementStatusFluent.DependentsNested<A> editFirstDependent();
    public RequirementStatusFluent.DependentsNested<A> editLastDependent();
    public RequirementStatusFluent.DependentsNested<A> editMatchingDependent(io.fabric8.kubernetes.api.builder.Predicate<DependentStatusBuilder> predicate);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(String arg1);
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(String arg1);
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(StringBuffer arg1);
    public String getUuid();
    public A withUuid(String uuid);
    public Boolean hasUuid();
    public A withNewUuid(String arg1);
    public A withNewUuid(StringBuilder arg1);
    public A withNewUuid(StringBuffer arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(String arg1);
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(StringBuffer arg1);
    public interface DependentsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DependentStatusFluent<RequirementStatusFluent.DependentsNested<N>> {

        public N and();
        public N endDependent();    }


}

==> openshift-model-operatorhub-5.1.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/RequirementStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RequirementStatusFluent<A extends RequirementStatusFluent<A>> extends Fluent<A> {


    public A addToDependents(int index,DependentStatus item);
    public A setToDependents(int index,DependentStatus item);
    public A addToDependents(DependentStatus... items);
    public A addAllToDependents(Collection<DependentStatus> items);
    public A removeFromDependents(DependentStatus... items);
    public A removeAllFromDependents(Collection<DependentStatus> items);
    public A removeMatchingFromDependents(Predicate<DependentStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDependents instead.
 * @return The buildable object.
 */
@Deprecated public List<DependentStatus> getDependents();
    public List<DependentStatus> buildDependents();
    public DependentStatus buildDependent(int index);
    public DependentStatus buildFirstDependent();
    public DependentStatus buildLastDependent();
    public DependentStatus buildMatchingDependent(Predicate<DependentStatusBuilder> predicate);
    public Boolean hasMatchingDependent(Predicate<DependentStatusBuilder> predicate);
    public A withDependents(List<DependentStatus> dependents);
    public A withDependents(DependentStatus... dependents);
    public Boolean hasDependents();
    public RequirementStatusFluent.DependentsNested<A> addNewDependent();
    public RequirementStatusFluent.DependentsNested<A> addNewDependentLike(DependentStatus item);
    public RequirementStatusFluent.DependentsNested<A> setNewDependentLike(int index,DependentStatus item);
    public RequirementStatusFluent.DependentsNested<A> editDependent(int index);
    public RequirementStatusFluent.DependentsNested<A> editFirstDependent();
    public RequirementStatusFluent.DependentsNested<A> editLastDependent();
    public RequirementStatusFluent.DependentsNested<A> editMatchingDependent(Predicate<DependentStatusBuilder> predicate);
    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(String arg1);
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(String arg1);
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(StringBuffer arg1);
    public String getUuid();
    public A withUuid(String uuid);
    public Boolean hasUuid();
    public A withNewUuid(String arg1);
    public A withNewUuid(StringBuilder arg1);
    public A withNewUuid(StringBuffer arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(String arg1);
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(StringBuffer arg1);
    public interface DependentsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DependentStatusFluent<RequirementStatusFluent.DependentsNested<N>> {

            public N and();
            public N endDependent();    }


}
